<template>
  <el-dialog
    :title="!dataForm.id ? '新增' : '修改'"
    :close-on-click-modal="false"
    :visible.sync="visible"
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="dataForm"
      label-width="130px"
      class="l-mes"
    >
      <el-row>
        <el-col :span="12">
          <el-form-item label="零件" prop="partName">
            <el-input v-model="dataForm.partName" placeholder="零件" readonly>
              <el-button
                slot="append"
                icon="el-icon-search"
                @click="openPartDialog()"
              ></el-button>
            </el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="资源" prop="resourceName">
            <el-input
              v-model="dataForm.resourceName"
              placeholder="资源"
              readonly
            >
              <el-button
                slot="append"
                icon="el-icon-search"
                @click="openResourceDialog()"
              ></el-button>
            </el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="备注" prop="remark">
            <el-input v-model="dataForm.remark" placeholder="备注"></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="前置时间(分钟)" prop="setupTime">
            <el-input
              v-model="dataForm.setupTime"
              placeholder="前置时间"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="生产速率" prop="productionRate">
            <el-input
              v-model="dataForm.productionRate"
              placeholder="生产速率"
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="生产速率单位" prop="productionRateUnit">
            <el-select
              v-model="dataForm.productionRateUnit"
              placeholder="生产速率单位"
              filterable
              style="width: 100%"
            >
              <el-option
                v-for="item in productionRateUnits"
                :key="item.id"
                :label="item.label"
                :value="item.value"
              />
            </el-select>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="后处理时间(分钟)" prop="postProcessing">
            <el-input
              v-model="dataForm.postProcessing"
              placeholder="后处理时间"
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item
            label="材料后处理时间(分钟)"
            prop="materialPostProcessing"
          >
            <el-input
              v-model="dataForm.materialPostProcessing"
              placeholder="材料后处理时间"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="传输时间(分钟)" prop="transferTime">
            <el-input
              v-model="dataForm.transferTime"
              placeholder="传输时间"
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="最小流转批次" prop="minFlowBatch">
            <el-input
              v-model="dataForm.minFlowBatch"
              placeholder="最小流转批次"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="最小生产批次" prop="minProduceBatch">
            <el-input
              v-model="dataForm.minProduceBatch"
              placeholder="最小生产批次"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`dataFormSubmit`"
        >确定</el-button
      >
    </span>
    <partDialog :currshowlist.sync="showPart" @listenToPartEvent="selectPart" />
    <resourceDialog
      :currshowlist.sync="showResource"
      @listenToResourceEvent="selectResource"
    />
  </el-dialog>
</template>

<script>
import { getObj, addObj, putObj } from '@/api/aps/resourceduration'
import { remote } from '@/api/admin/dict'
import { validateNumber, validateValidity } from '../../../api/aps/validate'
import partDialog from '@/views/common/part.vue'
import resourceDialog from '@/views/common/resource.vue'
import { getPart, getResource } from '../../../api/aps/resourceduration'

export default {
  components: {
    partDialog,
    resourceDialog
  },
  data() {
    return {
      showResource: false,
      showPart: false,
      visible: false,
      dataForm: {
        id: 0,
        remark: '',
        setupTime: '',
        productionRate: '',
        productionRateUnit: '',
        postProcessing: '',
        materialPostProcessing: '',
        transferTime: '',
        resourceId: '',
        partName: '',
        partId: '',
        resourceName: '',
        minProduceBatch: null,
        minFlowBatch: null
      },

      dataRule: {
        partName: [
          { required: true, message: '零件号不能为空', trigger: 'blur' }
        ],
        resourceName: [
          { required: true, message: '资源代码不能为空', trigger: 'blur' }
        ],
        productionRate: [
          { required: true, message: '生产速率不能为空', trigger: 'blur' },
          { validator: validateValidity, trigger: 'blur' }
        ],
        productionRateUnit: [
          { required: true, message: '生产速率单位不能为空', trigger: 'blur' }
        ],
        setupTime: [
          { required: true, message: '前置时间不能为空', trigger: 'blur' },
          { validator: validateValidity, trigger: 'blur' }
        ],
        postProcessing: [
          { required: true, message: '后处理时间不能为空', trigger: 'blur' },
          { validator: validateValidity, trigger: 'blur' }
        ],
        materialPostProcessing: [
          { validator: validateValidity, trigger: 'blur' }
        ],
        transferTime: [{ validator: validateValidity, trigger: 'blur' }],
        minProduceBatch: [{ validator: validateValidity, trigger: 'blur' }],
        minFlowBatch: [{ validator: validateValidity, trigger: 'blur' }]
      },
      components: [],
      productionRateUnits: [],
      resourceOptions: [],
      options: [],
      loading: false,
      isSubmit: false
    }
  },
  created() {
    this.getDict()
  },
  methods: {
    // 打开弹窗
    openPartDialog() {
      this.showPart = true
    },
    openResourceDialog() {
      this.showResource = true
    },
    // 零件向form表单传值
    selectPart(part) {
      if (part) {
        this.$set(this.dataForm, 'partName', part.partNo + '-' + part.partName)
        this.dataForm.partId = part.id
        this.$refs.dataForm.validateField('partName', (valid) => {})
      }
    },
    selectResource(resource) {
      if (resource) {
        this.$set(
          this.dataForm,
          'resourceName',
          resource.resourceNo + '-' + resource.resourceName
        )
        this.dataForm.resourceId = resource.id
        this.$refs.dataForm.validateField('resourceName', (valid) => {})
      }
    },
    getDict() {
      remote('production_rate_unit').then((response) => {
        if (response.data.code === 0) {
          this.productionRateUnits = response.data.data
        }
      })
    },
    init(id) {
      this.dataForm.id = id || 0
      this.visible = true
      this.$nextTick(() => {
        this.$refs.dataForm.resetFields()
        if (this.dataForm.id) {
          getObj(this.dataForm.id).then((response) => {
            this.dataForm = response.data.data
            if (this.dataForm.partId) {
              getPart(this.dataForm.partId).then((response) => {
                this.selectPart(response.data.data)
              })
            }
            if (this.dataForm.resourceId) {
              getResource(this.dataForm.resourceId).then((response) => {
                this.selectResource(response.data.data)
              })
            }
          })
        }
      })
    },
    // 表单提交
    dataFormSubmit() {
      this.isSubmit = true
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          if (this.dataForm.id) {
            putObj(this.dataForm).then((data) => {
              this.$message.success('修改成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          } else {
            addObj(this.dataForm).then((data) => {
              this.$message.success('添加成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          }
        } else {
          this.isSubmit = false
        }
      })
    }
  }
}
</script>
